View source: R/regional.consistency.probs.R
| regional.consistency.probs | R Documentation |
This function calculates approximate regional consistency probabilities using Methods 1 and 2 proposed by Japanese MHLW (2007). The function can obtain:
Unconditional regional consistency probabilities
Joint regional consistency probabilities
Conditional regional consistency probabilities
For technical details, please see Homma (2024)
regional.consistency.probs(f.s, PI, alpha, power, seed)
f.s |
A numeric vector representing the proportion of patients in region s(=1,...,S) among patients in the entire trial population. Values must sum to 1. |
PI |
A numeric value specifying the threshold for Method 1 (typically set at 0.5). |
alpha |
A numeric value representing the one-sided level of significance. |
power |
A numeric value representing the target power. |
seed |
A random number seed. |
A list containing the following components:
The input proportion of patients in each region
The input threshold value for Method 1
The input one-sided significance level
The input target power
The input seed number
Unconditional regional consistency probability for Method 1
Joint regional consistency probability for Method 1
Conditional regional consistency probability for Method 1
Unconditional regional consistency probability for Method 2
Joint regional consistency probability for Method 2
Conditional regional consistency probability for Method 2
regional.consistency.probs(
f.s = c(0.1, 0.45, 0.45),
PI = 0.5,
alpha = 0.025,
power = 0.8,
seed = 123
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.